@@ -1,9 +1,6 @@
 #' @export
 ggplot2::unit
 
-#' @export
-scan::`%>%`
-
 #' @export
 ggplot2::element_line
 
@@ -13,4 +10,6 @@ ggplot2::element_text
 #' @export
 ggplot2::element_rect
 
+#' @export
+ggplot2::element_point
 
